@@ -4,5 +4,9 @@
 # (C) 2007, ZOPYX Ltd & Co. KG, Tuebingen, Germany
 ##########################################################################
 
+from interfaces import IFOConverter, IHTML2FOConverter, IXSLFOConverter
+
 from convert import Converter
-from interfaces import IFOConverter, IHTML2FOConverter
+from html2fo import HTML2FOConverter
+from fo2pdf import PDFConverter
+from fo2xfc import DOCXConverter, RTFConverter, ODTConverter, WMLConverter
