@@ -6,10 +6,11 @@
 
 import sys
 import tempfile
+import logging
 from subprocess import Popen, PIPE
 
 win32 = (sys.platform=='win32')
-
+LOG = logging.getLogger()
 
 def newTempfile(suffix=''):
     return tempfile.mktemp(suffix=suffix)
@@ -36,7 +37,9 @@ def runcmd(cmd):
         status = p.wait()
         stdout_ = p.stdout.read().strip()
         stderr_ = p.stderr.read().strip()
-        print stdout_
-        print stderr_
+        if stdout_:
+            LOG.info(stdout_)
+        if stderr_:
+            LOG.info(stderr_)
         return status, stdout_ + stderr_
 
